pub struct SessionId(/* private fields */);Expand description
Remote agent session ID.
Session IDs are acquired when registering as a remote agent with the Datadog Agent. This session ID must be provided when refreshing a remote agent’s registration, as well as when streaming configuration updates. To ease passing this in the necessary format, and with the required validation, this struct provides a type-safe to carry around the session ID compared to a raw string.
Implementations
Sourceimpl SessionId
impl SessionId
Sourcepub fn new(session_id: &str) -> Result<Self, GenericError>
pub fn new(session_id: &str) -> Result<Self, GenericError>
Creates a new SessionId from the given string.
Errors
If the given string isn’t valid ASCII, an error is returned.
Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Returns a reference to the string representation of the session ID.
Sourcepub fn to_grpc_header_value(&self) -> MetadataValue<Ascii>
pub fn to_grpc_header_value(&self) -> MetadataValue<Ascii>
Returns the session ID as a metadata header value.